@@ -65,7 +65,7 @@ sub _generic {
     my ( $opt, $info, $webpage_url ) = @_;
     my $message = "Fetching download info: ";
     my $tmp = get_download_info( $opt, $webpage_url, $message );
-    next if ! defined $tmp;
+    return if ! defined $tmp;
     my ( $ex ) = keys %$tmp;
     my @keys = keys %{$tmp->{$ex}};
     if ( @keys == 1 ) {
