@@ -15,73 +15,15 @@ use App::YTDL::Helper qw( read_json write_json );
 
 
 
-sub __read_history_files {  #### use this after some time ####
+sub read_history_files {
     my ( $opt ) = @_;
     $opt->{sticky}  = {};
     $opt->{history} = {};
     if ( $opt->{max_size_history} ) {
-        $opt->{sticky}  = read_json( $opt, $opt->{sticky_file} )  // {}  if -e $opt->{sticky_file};
+        $opt->{sticky}  = read_json( $opt, $opt->{sticky_file} )  // {} if -e $opt->{sticky_file};
         $opt->{history} = read_json( $opt, $opt->{history_file} ) // {} if -e $opt->{history_file};
     }
 }
-sub read_history_files {  #### keep this for some time ####
-    my ( $opt ) = @_;
-    require File::Spec::Functions;
-    my $old_history_file = File::Spec::Functions::catfile( $opt->{config_dir}, 'channel_history.json' );
-    my $old_sticky_file  = File::Spec::Functions::catfile( $opt->{config_dir}, 'channel_sticky.json' );
-    $opt->{sticky}  = {};
-    $opt->{history} = {};
-    if ( $opt->{max_size_history} ) {
-        if ( -e $opt->{sticky_file} ) {
-            $opt->{sticky} = read_json( $opt, $opt->{sticky_file} ) // {};
-        }
-        elsif ( -e $old_sticky_file ) {
-            $opt->{sticky} = read_json( $opt, $old_sticky_file ) // {};
-            for my $url ( keys %{$opt->{sticky}} ) {
-                $opt->{sticky}{$url}{uploader}    =         delete $opt->{sticky}{$url}{channel}       if $opt->{sticky}{$url}{channel};
-                $opt->{sticky}{$url}{uploader_id} =         delete $opt->{sticky}{$url}{channel_id}    if $opt->{sticky}{$url}{channel_id};
-                $opt->{sticky}{$url}{extractor}   = lcfirst delete $opt->{sticky}{$url}{extractor_key} if $opt->{sticky}{$url}{extractor_key};
-                delete $opt->{sticky}{$url}{channel_url};
-                if ( $opt->{sticky}{$url}{extractor} eq 'youtube' ) {
-                    if ( $url =~ /^c#([^#]+)\z/ ) {
-                        my $new_url = "https://www.youtube.com/user/$1";
-                        $opt->{sticky}{$new_url} = delete $opt->{sticky}{$url};
-                    }
-                }
-                if ( $url =~ /^http:(.+)\z/ ) {
-                    my $new_url = "https:$1";
-                    $opt->{sticky}{$new_url} = delete $opt->{sticky}{$url};
-                }
-            }
-        write_json( $opt, $opt->{sticky_file},  $opt->{sticky} );
-        unlink $old_sticky_file or warn $!;
-        }
-        if ( -e $opt->{history_file} ) {
-            $opt->{history} = read_json( $opt, $opt->{history_file} ) // {};
-        }
-        elsif ( -e $old_history_file ) {
-            $opt->{history} = read_json( $opt, $old_history_file ) // {};
-            for my $url ( keys %{$opt->{history}} ) {
-                $opt->{history}{$url}{uploader}    =         delete $opt->{history}{$url}{channel}       if $opt->{history}{$url}{channel};
-                $opt->{history}{$url}{uploader_id} =         delete $opt->{history}{$url}{channel_id}    if $opt->{history}{$url}{channel_id};
-                $opt->{history}{$url}{extractor}   = lcfirst delete $opt->{history}{$url}{extractor_key} if $opt->{history}{$url}{extractor_key};
-                delete $opt->{history}{$url}{channel_url};
-                if ( $opt->{history}{$url}{extractor} eq 'youtube' ) {
-                    if ( $url =~ /^c#([^#]+)\z/ ) {
-                        my $new_url = "https://www.youtube.com/user/$1";
-                        $opt->{history}{$new_url} = delete $opt->{history}{$url};
-                    }
-                }
-                if ( $url =~ /^http:(.+)\z/ ) {
-                    my $new_url = "https:$1";
-                    $opt->{history}{$new_url} = delete $opt->{history}{$url};
-                }
-            }
-            write_json( $opt, $opt->{history_file}, $opt->{history} );
-            unlink $old_history_file or warn $!;
-        }
-    }
-}
 
 
 sub uploader_history_menu {
